==> qtjambi-help-6.5.4-sources.jar: io/qt/help/QHelpContentModel.java <==
package io.qt.help;

import io.qt.*;


/**
 * <p>Model that supplies content to views</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html">QHelpContentModel</a></code></p>
 */
public final class QHelpContentModel extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentModel.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentsCreated">QHelpContentModel::<wbr/>contentsCreated()</a></code></p>
     */
    public final @NonNull Signal0 contentsCreated = new Signal0();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentsCreationStarted">QHelpContentModel::<wbr/>contentsCreationStarted()</a></code></p>
     */
    public final @NonNull Signal0 contentsCreationStarted = new Signal0();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentItemAt">QHelpContentModel::<wbr/>contentItemAt(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.help.@Nullable QHelpContentItem contentItemAt(io.qt.core.@NonNull QModelIndex index){
        return contentItemAt_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index));
    }
    
    @QtUninvokable
    private native io.qt.help.QHelpContentItem contentItemAt_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#createContents">QHelpContentModel::<wbr/>createContents(QString)</a></code></p>
     */
    @QtUninvokable
    public final void createContents(java.lang.@NonNull String customFilterName){
        createContents_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customFilterName);
    }
    
    @QtUninvokable
    private native void createContents_native_cref_QString(long __this__nativeId, java.lang.String customFilterName);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#isCreatingContents">QHelpContentModel::<wbr/>isCreatingContents()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isCreatingContents(){
        return isCreatingContents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isCreatingContents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#columnCount">QAbstractItemModel::<wbr/>columnCount(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public int columnCount(io.qt.core.@NonNull QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#data">QAbstractItemModel::<wbr/>data(QModelIndex,<wbr/>int)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public java.lang.Object data(io.qt.core.@NonNull QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), role);
    }
    
    @QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, long index, int role);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#index">QAbstractItemModel::<wbr/>index(int,<wbr/>int,<wbr/>QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.core.@NonNull QModelIndex index(int row, int column, io.qt.core.@NonNull QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, long parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#parent">QAbstractItemModel::<wbr/>parent(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.core.@NonNull QModelIndex parent(io.qt.core.@NonNull QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#rowCount">QAbstractItemModel::<wbr/>rowCount(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public int rowCount(io.qt.core.@NonNull QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QHelpContentModel(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.7.1-sources.jar: io/qt/help/QHelpContentModel.java <==
package io.qt.help;

import io.qt.*;


/**
 * <p>Model that supplies content to views</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html">QHelpContentModel</a></code></p>
 */
public final class QHelpContentModel extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentModel.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentsCreated">QHelpContentModel::<wbr/>contentsCreated()</a></code></p>
     */
    public final @NonNull Signal0 contentsCreated = new Signal0();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentsCreationStarted">QHelpContentModel::<wbr/>contentsCreationStarted()</a></code></p>
     */
    public final @NonNull Signal0 contentsCreationStarted = new Signal0();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentItemAt">QHelpContentModel::<wbr/>contentItemAt(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.help.@Nullable QHelpContentItem contentItemAt(io.qt.core.@NonNull QModelIndex index){
        return contentItemAt_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index));
    }
    
    @QtUninvokable
    private native io.qt.help.QHelpContentItem contentItemAt_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#createContents">QHelpContentModel::<wbr/>createContents(QString)</a></code></p>
     */
    @QtUninvokable
    public final void createContents(java.lang.@NonNull String customFilterName){
        createContents_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customFilterName);
    }
    
    @QtUninvokable
    private native void createContents_native_cref_QString(long __this__nativeId, java.lang.String customFilterName);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentmodel.html#isCreatingContents">QHelpContentModel::<wbr/>isCreatingContents()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isCreatingContents(){
        return isCreatingContents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isCreatingContents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#columnCount">QAbstractItemModel::<wbr/>columnCount(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public int columnCount(io.qt.core.@NonNull QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#data">QAbstractItemModel::<wbr/>data(QModelIndex,<wbr/>int)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public java.lang.Object data(io.qt.core.@NonNull QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), role);
    }
    
    @QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, long index, int role);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#index">QAbstractItemModel::<wbr/>index(int,<wbr/>int,<wbr/>QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.core.@NonNull QModelIndex index(int row, int column, io.qt.core.@NonNull QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, long parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#parent">QAbstractItemModel::<wbr/>parent(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.core.@NonNull QModelIndex parent(io.qt.core.@NonNull QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstractitemmodel.html#rowCount">QAbstractItemModel::<wbr/>rowCount(QModelIndex)const</a></code></p>
     */
    @QtUninvokable
    @Override
    public int rowCount(io.qt.core.@NonNull QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    private QHelpContentModel(QPrivateConstructor p) { super(p); } 
    
}
